@@ -4,20 +4,20 @@
 # Settings
 PKG="drbl"
 FILES_DIRS="Makefile drbl.spec sbin bin doc lang pkg scripts themes conf image pki setup prerun postrun"
-SPEC_FILE="$PKG.spec"
+# SPEC_FILE="$PKG.spec"
 
 set -e
 #
 VER="$(LC_ALL=C head -n 1 debian/changelog  | grep -i "^${PKG}" | grep -E -o "\(.*\)" | sed -r -e "s/\(//g" -e "s/\)//g" | cut -d"-" -f1)"
 [ -z "$VER" ] && echo "No version found in debian/changelog! Program terminated!"
 echo "VER: $VER"
-RPM_VER=`grep ^Version $SPEC_FILE |sed -e "s/\t/ /g" -e "s/ \+/ /g" |cut  -d":" -f2 |tr -d " "`
-echo "RPM VER: $RPM_VER"
-if [ "$VER" != "$RPM_VER" ]; then
-  echo "Versions do not match!"
-  echo "Program terminated!"
-  exit 1
-fi
+# RPM_VER=`grep ^Version $SPEC_FILE |sed -e "s/\t/ /g" -e "s/ \+/ /g" |cut  -d":" -f2 |tr -d " "`
+# echo "RPM VER: $RPM_VER"
+# if [ "$VER" != "$RPM_VER" ]; then
+#   echo "Versions do not match!"
+#   echo "Program terminated!"
+#   exit 1
+# fi
 
 # Create the ChangeLog file
 cat <<EOF > doc/ChangeLog.txt
